@@ -15,15 +15,20 @@ from covsirphy.util.map import jpn_map
 from covsirphy.util.optimize import Optimizer
 from covsirphy.util.stopwatch import StopWatch
 from covsirphy.util.error import deprecate
+from covsirphy.util.error import SubsetNotFoundError, ScenarioNotFoundError, UnExecutedError
+from covsirphy.util.error import PCRIncorrectPreconditionError
 from covsirphy.util.file import save_dataframe
 from covsirphy.util.argument import find_args
 # cleaning
 from covsirphy.cleaning.term import Term, Word
 from covsirphy.cleaning.cbase import CleaningBase
 from covsirphy.cleaning.jhu_data import JHUData
+from covsirphy.cleaning.jhu_complement import JHUDataComplementHandler
 from covsirphy.cleaning.country_data import CountryData
+from covsirphy.cleaning.japan_data import JapanData
 from covsirphy.cleaning.population import PopulationData, Population
 from covsirphy.cleaning.oxcgrt import OxCGRTData
+from covsirphy.cleaning.pcr_data import PCRData
 from covsirphy.cleaning.covid19datahub import COVID19DataHub
 from covsirphy.cleaning.linelist import LinelistData
 from covsirphy.cleaning.dataloader import DataLoader
@@ -45,6 +50,7 @@ from covsirphy.phase.phase_series import PhaseSeries
 from covsirphy.phase.phase_estimator import MPEstimator
 # analysis
 from covsirphy.analysis.example_data import ExampleData
+from covsirphy.analysis.data_handler import DataHandler
 from covsirphy.analysis.param_tracker import ParamTracker
 from covsirphy.analysis.scenario import Scenario
 from covsirphy.analysis.model_validator import ModelValidator
@@ -61,16 +67,18 @@ def get_version():
 
 __all__ = [
     "ExampleData", "Scenario", "ModelValidator", "ParamTracker",
-    "ODESimulator", "ChangeFinder",
+    "ODESimulator", "ChangeFinder", "DataHandler",
     "PhaseSeries", "PhaseUnit", "MPEstimator",
     "Term", "CleaningBase", "DataLoader", "COVID19DataHub",
     "JHUData", "CountryData", "PopulationData", "OxCGRTData",
-    "LinelistData",
+    "LinelistData", "PCRData", "JapanData", "JHUDataComplementHandler",
     "ModelBase", "SIR", "SIRD", "SIRF", "SIRFV", "SEWIRF",
     "Estimator", "Trend", "Optimizer",
     "line_plot", "jpn_map", "StopWatch", "deprecate", "find_args",
     "save_dataframe",
     "PolicyMeasures",
+    "SubsetNotFoundError", "ScenarioNotFoundError", "UnExecutedError",
+    "PCRIncorrectPreconditionError",
     # Deprecated
     "Population", "Word",
 ]
