@@ -32,17 +32,17 @@ class SIRF(ModelBase):
     }
     VARIABLES = list(VAR_DICT.values())
     # Weights of variables in parameter estimation error function
-    WEIGHTS = np.array([1, 1, 1, 1])
+    WEIGHTS = np.array([0, 1, 1, 1])
     # Variables that increases monotonically
     VARS_INCLEASE = [ModelBase.R, ModelBase.F]
     # Example set of parameters and initial values
     EXAMPLE = {
-        "step_n": 180,
-        "population": 1_000_000,
-        "param_dict": {
+        ModelBase.STEP_N: 180,
+        ModelBase.N.lower(): 1_000_000,
+        ModelBase.PARAM_DICT: {
             "theta": 0.002, "kappa": 0.005, "rho": 0.2, "sigma": 0.075,
         },
-        "y0_dict": {
+        ModelBase.Y0_DICT: {
             ModelBase.S: 999_000, ModelBase.CI: 1000, ModelBase.R: 0, ModelBase.F: 0,
         },
     }
@@ -101,6 +101,7 @@ class SIRF(ModelBase):
         df = cls.ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
+        df = df.loc[(df[cls.S] > 0) & (df[cls.CI] > 0)]
         n, t = population, df[cls.TS]
         s, i, r = df[cls.S], df[cls.CI], df[cls.R]
         # rho = - n * (dS/dt) / S / I
@@ -109,7 +110,7 @@ class SIRF(ModelBase):
         sigma_series = r.diff() / t.diff() / i
         # Calculate quantile
         _dict = {
-            k: v.quantile(cls.QUANTILE_RANGE)
+            k: tuple(v.quantile(cls.QUANTILE_RANGE).clip(0, 1))
             for (k, v) in zip(["rho", "sigma"], [rho_series, sigma_series])
         }
         _dict["theta"] = (0, 1)
